@@ -42,6 +42,10 @@ def get_time(text: str, tend_future=True):
                     if t1 and t1 > now:
                         t1 = t1 - relativedelta(weeks=1)
                         t2 = t2 - relativedelta(weeks=1)
+        if isinstance(t1, datetime):
+            t1 = t1.strftime(time_format)
+        if isinstance(t2, datetime):
+            t2 = t2.strftime(time_format)
         time_tuple = (t1, t2)
     except ValueError as _:
         pass
